@@ -62,6 +62,7 @@ from google.cloud.contentwarehouse_v1.types import document as gcc_document
 from .transports.base import DEFAULT_CLIENT_INFO, DocumentServiceTransport
 from .transports.grpc import DocumentServiceGrpcTransport
 from .transports.grpc_asyncio import DocumentServiceGrpcAsyncIOTransport
+from .transports.rest import DocumentServiceRestTransport
 
 
 class DocumentServiceClientMeta(type):
@@ -77,6 +78,7 @@ class DocumentServiceClientMeta(type):
     )  # type: Dict[str, Type[DocumentServiceTransport]]
     _transport_registry["grpc"] = DocumentServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = DocumentServiceGrpcAsyncIOTransport
+    _transport_registry["rest"] = DocumentServiceRestTransport
 
     def get_transport_class(
         cls,
